@@ -13,30 +13,39 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #ifndef  __BRUSH_SELECT_H__
 #define  __BRUSH_SELECT_H__
 
-#include "image_buf.h"
+#include "buildmenu.h"
 
 typedef struct _BrushSelect _BrushSelect, *BrushSelectP;
 
 struct _BrushSelect {
-  Widget            shell;
-  Widget            dialog;
-  Widget            swin;
-  Widget            preview;
-  Widget            active_brush;
-  ImageBuf          image;
-  int               width, height;
-  int               cell_width, cell_height;
-  GC                gc;
+  GtkWidget *shell;
+  GtkWidget *frame;
+  GtkWidget *preview;
+  GtkWidget *brush_name;
+  GtkWidget *brush_size;
+  GtkWidget *options_box;
+  GtkAdjustment *opacity_data;
+  GtkAdjustment *spacing_data;
+  GtkAdjustment *sbar_data;
+  int width, height;
+  int cell_width, cell_height;
+  int scroll_offset;
+  int redraw;
+  /*  Brush preview  */
+  GtkWidget *brush_popup;
+  GtkWidget *brush_preview;
 };
 
 BrushSelectP  brush_select_new     (void);
 void          brush_select_select  (BrushSelectP, int);
 void          brush_select_free    (BrushSelectP);
 
+/*  An interface to other dialogs which need to create a paint mode menu  */
+GtkWidget *   create_paint_mode_menu (MenuItemCallback);
 
 #endif  /*  __BRUSH_SELECT_H__  */
