@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #include <stdlib.h>
 #include <string.h>
@@ -79,7 +79,7 @@ struct _LevelsDialog
   GtkWidget *    channel_menu;
   Histogram *    histogram;
 
-  int            drawable_id;
+  GimpDrawable * drawable;
   ImageMap       image_map;
   int            color;
   int            channel;
@@ -118,6 +118,7 @@ static void            levels_alpha_callback          (GtkWidget *, gpointer);
 static void            levels_auto_levels_callback    (GtkWidget *, gpointer);
 static void            levels_ok_callback             (GtkWidget *, gpointer);
 static void            levels_cancel_callback         (GtkWidget *, gpointer);
+static gint            levels_delete_callback         (GtkWidget *, GdkEvent *, gpointer);
 static void            levels_preview_update          (GtkWidget *, gpointer);
 static void            levels_low_input_text_update   (GtkWidget *, gpointer);
 static void            levels_gamma_text_update       (GtkWidget *, gpointer);
@@ -204,6 +205,9 @@ levels_histogram_info (PixelRegion     *srcPR,
   int value, red, green, blue;
   int has_alpha, alpha;
 
+  mask = NULL;
+  m    = NULL;
+
   ld = (LevelsDialog *) user_data;
 
   h = srcPR->h;
@@ -297,6 +301,10 @@ levels_button_press (Tool           *tool,
 		     GdkEventButton *bevent,
 		     gpointer        gdisp_ptr)
 {
+  GDisplay *gdisp;
+
+  gdisp = gdisp_ptr;
+  tool->drawable = gimage_active_drawable (gdisp->gimage);
 }
 
 static void
@@ -342,7 +350,9 @@ levels_control (Tool     *tool,
     case HALT :
       if (levels_dialog)
 	{
+	  active_tool->preserve = TRUE;
 	  image_map_abort (levels_dialog->image_map);
+	  active_tool->preserve = FALSE;
 	  levels_dialog->image_map = NULL;
 	  levels_cancel_callback (NULL, (gpointer) levels_dialog);
 	}
@@ -374,6 +384,9 @@ tools_new_levels ()
   tool->arrow_keys_func = standard_arrow_keys_func;
   tool->cursor_update_func = levels_cursor_update;
   tool->control_func = levels_control;
+  tool->preserve = FALSE;
+  tool->gdisp_ptr = NULL;
+  tool->drawable = NULL;
 
   return tool;
 }
@@ -387,7 +400,7 @@ tools_free_levels (Tool *tool)
 
   /*  Close the color select dialog  */
   if (levels_dialog)
-    levels_ok_callback (NULL, (gpointer) levels_dialog);
+    levels_cancel_callback (NULL, (gpointer) levels_dialog);
 
   g_free (_levels);
 }
@@ -412,7 +425,7 @@ levels_initialize (void *gdisp_ptr)
 
   if (drawable_indexed (gimage_active_drawable (gdisp->gimage)))
     {
-      message_box ("Levels for indexed drawables cannot be adjusted.", NULL, NULL);
+      g_message ("Levels for indexed drawables cannot be adjusted.");
       return;
     }
 
@@ -434,12 +447,12 @@ levels_initialize (void *gdisp_ptr)
       levels_dialog->high_output[i] = 255;
     }
 
-  levels_dialog->drawable_id = gimage_active_drawable (gdisp->gimage);
-  levels_dialog->color = drawable_color (levels_dialog->drawable_id);
-  levels_dialog->image_map = image_map_create (gdisp_ptr, levels_dialog->drawable_id);
+  levels_dialog->drawable = gimage_active_drawable (gdisp->gimage);
+  levels_dialog->color = drawable_color (levels_dialog->drawable);
+  levels_dialog->image_map = image_map_create (gdisp_ptr, levels_dialog->drawable);
 
   /* check for alpha channel */
-  if (drawable_has_alpha (levels_dialog->drawable_id))
+  if (drawable_has_alpha (levels_dialog->drawable))
     gtk_widget_set_sensitive( color_option_items[4].widget, TRUE);
   else 
     gtk_widget_set_sensitive( color_option_items[4].widget, FALSE);
@@ -460,7 +473,7 @@ levels_initialize (void *gdisp_ptr)
   levels_update (levels_dialog, INPUT_LEVELS | OUTPUT_LEVELS);
 
   histogram_update (levels_dialog->histogram,
-		    levels_dialog->drawable_id,
+		    levels_dialog->drawable,
 		    levels_histogram_info,
 		    (void *) levels_dialog);
   histogram_range (levels_dialog->histogram, -1, -1);
@@ -473,7 +486,9 @@ levels_free ()
     {
       if (levels_dialog->image_map)
 	{
+	  active_tool->preserve = TRUE;
 	  image_map_abort (levels_dialog->image_map);
+	  active_tool->preserve = FALSE;
 	  levels_dialog->image_map = NULL;
 	}
       gtk_widget_destroy (levels_dialog->shell);
@@ -492,7 +507,7 @@ static ActionAreaItem action_items[] =
   { "Cancel", levels_cancel_callback, NULL, NULL }
 };
 
-LevelsDialog *
+static LevelsDialog *
 levels_new_dialog ()
 {
   LevelsDialog *ld;
@@ -514,8 +529,14 @@ levels_new_dialog ()
 
   /*  The shell and main vbox  */
   ld->shell = gtk_dialog_new ();
+  gtk_window_set_wmclass (GTK_WINDOW (ld->shell), "levels", "Gimp");
   gtk_window_set_title (GTK_WINDOW (ld->shell), "Levels");
 
+  /* handle the wm close signal */
+  gtk_signal_connect (GTK_OBJECT (ld->shell), "delete_event",
+		      GTK_SIGNAL_FUNC (levels_delete_callback),
+		      ld);
+
   vbox = gtk_vbox_new (FALSE, 2);
   gtk_container_border_width (GTK_CONTAINER (vbox), 2);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (ld->shell)->vbox), vbox, TRUE, TRUE, 0);
@@ -885,7 +906,9 @@ levels_preview (LevelsDialog *ld)
 {
   if (!ld->image_map)
     g_warning ("No image map");
+  active_tool->preserve = TRUE;
   image_map_apply (ld->image_map, levels, (void *) ld);
+  active_tool->preserve = FALSE;
 }
 
 static void
@@ -1064,15 +1087,29 @@ levels_ok_callback (GtkWidget *widget,
   if (GTK_WIDGET_VISIBLE (ld->shell))
     gtk_widget_hide (ld->shell);
 
+  active_tool->preserve = TRUE;
+
   if (!ld->preview)
     image_map_apply (ld->image_map, levels, (void *) ld);
 
   if (ld->image_map)
     image_map_commit (ld->image_map);
 
+  active_tool->preserve = FALSE;
+
   ld->image_map = NULL;
 }
 
+static gint
+levels_delete_callback (GtkWidget *w,
+			GdkEvent *e,
+			gpointer client_data)
+{
+  levels_cancel_callback (w, client_data);
+
+  return TRUE;
+}
+
 static void
 levels_cancel_callback (GtkWidget *widget,
 			gpointer   client_data)
@@ -1085,7 +1122,9 @@ levels_cancel_callback (GtkWidget *widget,
 
   if (ld->image_map)
     {
+      active_tool->preserve = TRUE;
       image_map_abort (ld->image_map);
+      active_tool->preserve = TRUE;
       gdisplays_flush ();
     }
 
@@ -1468,7 +1507,7 @@ levels_invoker (Argument *args)
   int success = TRUE;
   LevelsDialog ld;
   GImage *gimage;
-  int drawable_id;
+  GimpDrawable *drawable;
   int channel;
   int low_input;
   int high_input;
@@ -1481,6 +1520,13 @@ levels_invoker (Argument *args)
   int i;
   void *pr;
 
+  drawable = NULL;
+  low_input   = 0;
+  high_input  = 0;
+  gamma       = 1.0;
+  low_output  = 0;
+  high_output = 0;
+
   /*  the gimage  */
   if (success)
     {
@@ -1492,23 +1538,26 @@ levels_invoker (Argument *args)
   if (success)
     {
       int_value = args[1].value.pdb_int;
-      if (gimage == drawable_gimage (int_value))
-	drawable_id = int_value;
-      else
+      drawable = drawable_get_ID (int_value);
+      if (drawable == NULL || gimage != drawable_gimage (drawable))
 	success = FALSE;
     }
+  /*  make sure the drawable is not indexed color  */
+  if (success)
+    success = ! drawable_indexed (drawable);
+   
   /*  channel  */
   if (success)
     {
       int_value = args[2].value.pdb_int;
       if (success)
 	{
-	  if (drawable_gray (drawable_id))
+	  if (drawable_gray (drawable))
 	    {
 	      if (int_value != 0)
 		success = FALSE;
 	    }
-	  else if (drawable_color (drawable_id))
+	  else if (drawable_color (drawable))
 	    {
 	      if (int_value < 0 || int_value > 3)
 		success = FALSE;
@@ -1577,7 +1626,7 @@ levels_invoker (Argument *args)
 	}
 
       ld.channel = channel;
-      ld.color = drawable_color (drawable_id);
+      ld.color = drawable_color (drawable);
       ld.low_input[channel] = low_input;
       ld.high_input[channel] = high_input;
       ld.gamma[channel] = gamma;
@@ -1588,16 +1637,16 @@ levels_invoker (Argument *args)
       levels_calculate_transfers (&ld);
 
       /*  The application should occur only within selection bounds  */
-      drawable_mask_bounds (drawable_id, &x1, &y1, &x2, &y2);
+      drawable_mask_bounds (drawable, &x1, &y1, &x2, &y2);
 
-      pixel_region_init (&srcPR, drawable_data (drawable_id), x1, y1, (x2 - x1), (y2 - y1), FALSE);
-      pixel_region_init (&destPR, drawable_shadow (drawable_id), x1, y1, (x2 - x1), (y2 - y1), TRUE);
+      pixel_region_init (&srcPR, drawable_data (drawable), x1, y1, (x2 - x1), (y2 - y1), FALSE);
+      pixel_region_init (&destPR, drawable_shadow (drawable), x1, y1, (x2 - x1), (y2 - y1), TRUE);
 
       for (pr = pixel_regions_register (2, &srcPR, &destPR); pr != NULL; pr = pixel_regions_process (pr))
 	levels (&srcPR, &destPR, (void *) &ld);
 
-      drawable_merge_shadow (drawable_id, TRUE);
-      drawable_update (drawable_id, x1, y1, (x2 - x1), (y2 - y1));
+      drawable_merge_shadow (drawable, TRUE);
+      drawable_update (drawable, x1, y1, (x2 - x1), (y2 - y1));
     }
 
   return procedural_db_return_args (&levels_proc, success);
