@@ -13,7 +13,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #ifndef __PENCIL_H__
 #define __PENCIL_H__
@@ -22,7 +22,7 @@
 #include "paint_core.h"
 #include "procedural_db.h"
 
-void *        pencil_paint_func  (PaintCore *, int, int);
+void *        pencil_paint_func  (PaintCore *, GimpDrawable *, int);
 Tool *        tools_new_pencil   (void);
 void          tools_free_pencil  (Tool *);
 
