@@ -13,14 +13,16 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
 #include <string.h>
-#include <regex.h>
+#include <sys/types.h>
+#include "regex.h"
 #include "appenv.h"
+#include "app_procs.h"
 #include "general.h"
 #include "gdisplay.h"
 #include "plug_in.h"
@@ -64,9 +66,7 @@ static Argument * procedural_db_set_data (Argument *);
 static Argument * procedural_db_query (Argument *);
 static void       procedural_db_query_entry (gpointer, gpointer, gpointer);
 static int        match_strings (regex_t *, char *);
-static guint      procedural_db_hash_func (gpointer key);
-static gint       procedural_db_compare_func (gpointer a, gpointer b);
-
+static guint      procedural_db_hash_func (gconstpointer key);
 
 /*  Local data  */
 static GHashTable *procedural_ht = NULL;
@@ -480,9 +480,10 @@ ProcRecord procedural_db_query_proc =
 void
 procedural_db_init ()
 {
+  app_init_update_status("Procedural Database", NULL, -1);
   if (!procedural_ht)
     procedural_ht = g_hash_table_new (procedural_db_hash_func,
-				      procedural_db_compare_func);
+				      g_str_equal);
 }
 
 void
@@ -553,6 +554,8 @@ procedural_db_execute (gchar    *name,
   GList *list;
   int i;
 
+  return_args = NULL;
+
   list = g_hash_table_lookup (procedural_ht, (gpointer) name);
 
   while (list)
@@ -571,11 +574,11 @@ procedural_db_execute (gchar    *name,
 	{
 	  if (args[i].arg_type != procedure->args[i].arg_type)
 	    {
-	      return_args = (Argument *) g_malloc (sizeof (Argument));
+	      return_args = (Argument *) g_malloc (sizeof (Argument) * (procedure->num_values + 1));
 	      return_args->arg_type = PDB_STATUS;
 	      return_args->value.pdb_int = PDB_CALLING_ERROR;
 
-	      g_warning ("PDB calling error %s", procedure->name);
+	      g_message ("PDB calling error %s", procedure->name);
 
 	      return return_args;
 	    }
@@ -589,19 +592,19 @@ procedural_db_execute (gchar    *name,
 	  break;
 
 	case PDB_PLUGIN:
-	  return_args = plug_in_run (procedure, args, TRUE);
+	  return_args = plug_in_run (procedure, args, TRUE, FALSE);
 	  break;
 
 	case PDB_EXTENSION:
-	  return_args = plug_in_run (procedure, args, TRUE);
+	  return_args = plug_in_run (procedure, args, TRUE, FALSE);
 	  break;
 
 	case PDB_TEMPORARY:
-	  return_args = plug_in_run (procedure, args, TRUE);
+	  return_args = plug_in_run (procedure, args, TRUE, FALSE);
 	  break;
 
 	default:
-	  return_args = (Argument *) g_malloc (sizeof (Argument));
+	  return_args = (Argument *) g_malloc (sizeof (Argument) * (procedure->num_values + 1));
 	  return_args->arg_type = PDB_STATUS;
 	  return_args->value.pdb_int = PDB_EXECUTION_ERROR;
 	  break;
@@ -651,7 +654,7 @@ procedural_db_run_proc (gchar *name,
     {
       if (proc->args[i].arg_type != (params[i].arg_type = va_arg (args, PDBArgType)))
 	{
-	  g_warning ("Incorrect arguments passed to procedural_db_run_proc");
+	  g_message ("Incorrect arguments passed to procedural_db_run_proc");
 	  g_free (params);
 	  return NULL;
 	}
@@ -1065,6 +1068,14 @@ procedural_db_query (Argument *args)
 
   g_hash_table_foreach (procedural_ht, procedural_db_query_entry, &pdb_query);
 
+  free (pdb_query.name_regex.buffer);
+  free (pdb_query.blurb_regex.buffer);
+  free (pdb_query.help_regex.buffer);
+  free (pdb_query.author_regex.buffer);
+  free (pdb_query.copyright_regex.buffer);
+  free (pdb_query.date_regex.buffer);
+  free (pdb_query.proc_type_regex.buffer);
+
   return_args = procedural_db_return_args (&procedural_db_query_proc, TRUE);
 
   return_args[1].value.pdb_int = pdb_query.num_procs;
@@ -1115,7 +1126,7 @@ match_strings (regex_t * preg,
 }
 
 static guint
-procedural_db_hash_func (gpointer key)
+procedural_db_hash_func (gconstpointer key)
 {
   gchar *string;
   guint result;
@@ -1159,9 +1170,4 @@ procedural_db_hash_func (gpointer key)
   return result;
 }
 
-static gint
-procedural_db_compare_func (gpointer a,
-			    gpointer b)
-{
-  return (strcmp ((char *) a, (char *) b) == 0);
-}
+
