@@ -13,26 +13,41 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #ifndef __RECT_SELECT_H__
 #define __RECT_SELECT_H__
 
+#include "procedural_db.h"
 #include "tools.h"
 
+typedef struct _SelectionOptions SelectionOptions;
+struct _SelectionOptions
+{
+  int antialias;
+  int feather;
+  double feather_radius;
+  int sample_merged;
+};
+
+SelectionOptions *create_selection_options  (ToolType);
+
 /*  rect select action functions  */
 
-void          rect_select_button_press      (Tool *, XButtonEvent *, XtPointer);
-void          rect_select_button_release    (Tool *, XButtonEvent *, XtPointer);
-void          rect_select_motion            (Tool *, XMotionEvent *, XtPointer);
-void          rect_select_control           (Tool *, int, void *);
+void          rect_select_button_press      (Tool *, GdkEventButton *, gpointer);
+void          rect_select_button_release    (Tool *, GdkEventButton *, gpointer);
+void          rect_select_motion            (Tool *, GdkEventMotion *, gpointer);
+void          rect_select_cursor_update     (Tool *, GdkEventMotion *, gpointer);
+void          rect_select_control           (Tool *, int, gpointer);
 
 
 /*  rect select functions  */
 
 void          rect_select_draw         (Tool *);
-Tool *        tools_new_rect_select    ();
+Tool *        tools_new_rect_select    (void);
 void          tools_free_rect_select   (Tool *);
 
+/*  Procedure definition and marshalling function  */
+extern ProcRecord rect_select_proc;
 
 #endif  /*  __RECT_SELECT_H__  */
