@@ -13,21 +13,26 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #ifndef __SCROLL_H__
 #define __SCROLL_H__
 
 #include "gdisplay.h"
 
+/*  app init and exit routines  */
+void init_scrolling (void);
+void free_scrolling (void);
+
 /*  routines for scrolling the image via the scrollbars  */
-void vert_scrolled (Widget, XtPointer, XtPointer);
-void horz_scrolled (Widget, XtPointer, XtPointer);
+void scrollbar_disconnect (GtkAdjustment *, gpointer);
+gint scrollbar_vert_update (GtkAdjustment *, gpointer);
+gint scrollbar_horz_update (GtkAdjustment *, gpointer);
 
 /*  routines for grabbing the image and scrolling via the pointer  */
-void start_grab_and_scroll (GDisplay *, XButtonPressedEvent *);
-void end_grab_and_scroll (GDisplay *, XButtonReleasedEvent *);
-void grab_and_scroll (Widget, XtPointer, XEvent *, Boolean *);
-void scroll_to_pointer_position (GDisplay *, XMotionEvent *);
+void start_grab_and_scroll (GDisplay *, GdkEventButton *);
+void end_grab_and_scroll (GDisplay *, GdkEventButton *);
+void grab_and_scroll (GDisplay *, GdkEventMotion *);
+void scroll_to_pointer_position (GDisplay *, GdkEventMotion *);
 
 #endif  /*  __SCROLL_H__  */
