@@ -17,11 +17,13 @@
  */
 
 
-/* 
+/*
    dbbrowser_utils.c
-   0.08  26th sept 97  by Thomas NOEL <thomas@minet.net> 
+   0.08  26th sept 97  by Thomas NOEL <thomas@minet.net>
 */
 
+#include <stdlib.h>
+
 #include "dbbrowser_utils.h"
 
 GList *proc_table;
@@ -41,49 +43,50 @@ gimp_db_browser(void (* apply_callback) ( gchar     *selected_proc_name,
 					  GParamDef *selected_return_vals ) )
   /* create the dialog box */
   /* console_entry != NULL => called from the script-fu-console */
- 
+
 {
-  
+
   dbbrowser_t* dbbrowser;
-  
+
   GtkWidget *button;
   GtkWidget *hbox,*searchhbox,*vbox;
   GtkWidget *label;
 
   dbbrowser = (gpointer)malloc(sizeof(dbbrowser_t));
-  
+
   dbbrowser->apply_callback = apply_callback;
-  
+
   /* the dialog box */
 
   dbbrowser->dlg = gtk_dialog_new ();
-  
+
   gtk_window_set_title (GTK_WINDOW (dbbrowser->dlg), "DB Browser (init)");
   gtk_window_position (GTK_WINDOW (dbbrowser->dlg), GTK_WIN_POS_MOUSE);
   gtk_signal_connect (GTK_OBJECT (dbbrowser->dlg), "destroy",
                       (GtkSignalFunc) dialog_close_callback,
                       dbbrowser);
-  
+
   /* hbox : left=list ; right=description */
-  
+
   hbox = gtk_hbox_new(FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dbbrowser->dlg)->vbox), 
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dbbrowser->dlg)->vbox),
 		      hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
-  
+
   /* left = vbox : the list and the search entry */
-  
+
   vbox = gtk_vbox_new( FALSE, 0 );
-  gtk_container_border_width (GTK_CONTAINER (vbox), 3); 
-  gtk_box_pack_start (GTK_BOX (hbox), 
+  gtk_container_border_width (GTK_CONTAINER (vbox), 3);
+  gtk_box_pack_start (GTK_BOX (hbox),
 		      vbox, FALSE, TRUE, 0);
   gtk_widget_show(vbox);
-  
+
   /* list : list in a scrolled_win */
-  
+
   dbbrowser->clist = gtk_clist_new(1);
-  gtk_clist_set_policy (GTK_CLIST (dbbrowser->clist), GTK_POLICY_AUTOMATIC,
-			GTK_POLICY_AUTOMATIC);
+  dbbrowser->scrolled_win = gtk_scrolled_window_new (NULL, NULL);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (dbbrowser->scrolled_win),
+                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_clist_set_selection_mode (GTK_CLIST (dbbrowser->clist),
 			        GTK_SELECTION_BROWSE);
 
@@ -91,9 +94,10 @@ gimp_db_browser(void (* apply_callback) ( gchar     *selected_proc_name,
   gtk_signal_connect (GTK_OBJECT (dbbrowser->clist), "select_row",
 		      (GtkSignalFunc) procedure_select_callback,
 		      dbbrowser);
-  gtk_box_pack_start (GTK_BOX (vbox), 
-		      dbbrowser->clist, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), dbbrowser->scrolled_win, TRUE, TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (dbbrowser->scrolled_win), dbbrowser->clist);
   gtk_widget_show(dbbrowser->clist);
+  gtk_widget_show(dbbrowser->scrolled_win);
 
   /* search entry */
 
@@ -104,12 +108,12 @@ gimp_db_browser(void (* apply_callback) ( gchar     *selected_proc_name,
 
   label = gtk_label_new("Search :");
   gtk_misc_set_alignment( GTK_MISC(label), 0.0, 0.5);
-  gtk_box_pack_start (GTK_BOX (searchhbox), 
+  gtk_box_pack_start (GTK_BOX (searchhbox),
 		      label, TRUE, TRUE, 0);
   gtk_widget_show(label);
 
   dbbrowser->search_entry = gtk_entry_new();
-  gtk_box_pack_start (GTK_BOX (searchhbox), 
+  gtk_box_pack_start (GTK_BOX (searchhbox),
 		      dbbrowser->search_entry, TRUE, TRUE, 0);
   gtk_widget_show(dbbrowser->search_entry);
 
@@ -117,10 +121,10 @@ gimp_db_browser(void (* apply_callback) ( gchar     *selected_proc_name,
 
   dbbrowser->descr_scroll = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (dbbrowser->descr_scroll),
-				  GTK_POLICY_ALWAYS, 
+				  GTK_POLICY_ALWAYS,
 				  GTK_POLICY_ALWAYS
 				  );
-  gtk_box_pack_start (GTK_BOX (hbox), 
+  gtk_box_pack_start (GTK_BOX (hbox),
 		      dbbrowser->descr_scroll, TRUE, TRUE, 0);
   gtk_widget_set_usize (dbbrowser->descr_scroll, DBL_WIDTH - DBL_LIST_WIDTH, 0);
   gtk_widget_show (dbbrowser->descr_scroll);
@@ -133,7 +137,7 @@ gimp_db_browser(void (* apply_callback) ( gchar     *selected_proc_name,
   GTK_WIDGET_SET_FLAGS (dbbrowser->name_button, GTK_CAN_DEFAULT);
   gtk_signal_connect (GTK_OBJECT (dbbrowser->name_button), "clicked",
                       (GtkSignalFunc) dialog_search_callback, dbbrowser);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dbbrowser->dlg)->action_area), 
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dbbrowser->dlg)->action_area),
 		    dbbrowser->name_button , TRUE, TRUE, 0);
   gtk_widget_show(dbbrowser->name_button);
 
@@ -141,7 +145,7 @@ gimp_db_browser(void (* apply_callback) ( gchar     *selected_proc_name,
   GTK_WIDGET_SET_FLAGS (dbbrowser->blurb_button, GTK_CAN_DEFAULT);
   gtk_signal_connect (GTK_OBJECT (dbbrowser->blurb_button), "clicked",
                       (GtkSignalFunc) dialog_search_callback, dbbrowser);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dbbrowser->dlg)->action_area), 
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dbbrowser->dlg)->action_area),
 		    dbbrowser->blurb_button , TRUE, TRUE, 0);
   gtk_widget_show(dbbrowser->blurb_button);
 
@@ -150,7 +154,7 @@ gimp_db_browser(void (* apply_callback) ( gchar     *selected_proc_name,
     GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
     gtk_signal_connect (GTK_OBJECT (button), "clicked",
 			(GtkSignalFunc) dialog_apply_callback, dbbrowser );
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dbbrowser->dlg)->action_area), 
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dbbrowser->dlg)->action_area),
 			button, TRUE, TRUE, 0);
     gtk_widget_show (button);
   }
@@ -159,14 +163,14 @@ gimp_db_browser(void (* apply_callback) ( gchar     *selected_proc_name,
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) dialog_close_callback, dbbrowser);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dbbrowser->dlg)->action_area), 
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dbbrowser->dlg)->action_area),
 		      button, TRUE, TRUE, 0);
   gtk_widget_show (button);
 
 
   /* now build the list */
 
-  gtk_widget_show (dbbrowser->clist); 
+  gtk_widget_show (dbbrowser->clist);
   gtk_widget_show (dbbrowser->dlg);
 
   /* initialize the "return" value (for "apply") */
@@ -194,8 +198,8 @@ gimp_db_browser(void (* apply_callback) ( gchar     *selected_proc_name,
 
 static gint
 procedure_select_callback (GtkWidget *widget,
-			   gint row, 
-			   gint column, 
+			   gint row,
+			   gint column,
 			   GdkEventButton * bevent,
 			   gpointer data)
 {
@@ -211,21 +215,21 @@ procedure_select_callback (GtkWidget *widget,
   return FALSE;
 }
 
-static void 
-dialog_select (dbbrowser_t *dbbrowser, 
+static void
+dialog_select (dbbrowser_t *dbbrowser,
 	       gchar       *proc_name)
   /* update the description box (right) */
 {
   GtkWidget* label, *old_table;
   gint i,row=0;
-  
-  if (dbbrowser->selected_proc_name) 
+
+  if (dbbrowser->selected_proc_name)
     g_free(dbbrowser->selected_proc_name);
   dbbrowser->selected_proc_name = g_strdup(proc_name);
 
   if (dbbrowser->selected_scheme_proc_name)
     g_free(dbbrowser->selected_scheme_proc_name);
-  dbbrowser->selected_scheme_proc_name = 
+  dbbrowser->selected_scheme_proc_name =
     g_strdup(proc_name);
   convert_string(dbbrowser->selected_scheme_proc_name);
 
@@ -237,22 +241,22 @@ dialog_select (dbbrowser_t *dbbrowser,
   if (dbbrowser->selected_params) g_free(dbbrowser->selected_params);
   if (dbbrowser->selected_return_vals) g_free(dbbrowser->selected_return_vals);
 
-  gimp_query_procedure (proc_name, 
-			&(dbbrowser->selected_proc_blurb), 
-			&(dbbrowser->selected_proc_help), 
+  gimp_query_procedure (proc_name,
+			&(dbbrowser->selected_proc_blurb),
+			&(dbbrowser->selected_proc_help),
 			&(dbbrowser->selected_proc_author),
-			&(dbbrowser->selected_proc_copyright), 
-			&(dbbrowser->selected_proc_date), 
-			&(dbbrowser->selected_proc_type), 
+			&(dbbrowser->selected_proc_copyright),
+			&(dbbrowser->selected_proc_date),
+			&(dbbrowser->selected_proc_type),
 			&(dbbrowser->selected_nparams),
-			&(dbbrowser->selected_nreturn_vals), 
-			&(dbbrowser->selected_params), 
+			&(dbbrowser->selected_nreturn_vals),
+			&(dbbrowser->selected_params),
 			&(dbbrowser->selected_return_vals));
 
   /* save the "old" table */
   old_table = dbbrowser->descr_table;
 
-  dbbrowser->descr_table = gtk_table_new( 
+  dbbrowser->descr_table = gtk_table_new(
        10 + dbbrowser->selected_nparams + dbbrowser->selected_nreturn_vals ,
        5 , FALSE );
 
@@ -261,7 +265,7 @@ dialog_select (dbbrowser_t *dbbrowser,
   /* show the name */
 
   label = gtk_label_new("Name :");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5); 
+  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
 		    0, 1, row, row+1, GTK_FILL, GTK_FILL, 3, 6);
   gtk_widget_show(label);
@@ -277,7 +281,7 @@ dialog_select (dbbrowser_t *dbbrowser,
   /* show the description */
 
   label = gtk_label_new("Blurb :");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5); 
+  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
 		    0, 1, row, row+1, GTK_FILL, GTK_FILL, 3, 0);
   gtk_widget_show(label);
@@ -296,19 +300,19 @@ dialog_select (dbbrowser_t *dbbrowser,
   row++;
 
   /* in parameters */
-  if (dbbrowser->selected_nparams) 
+  if (dbbrowser->selected_nparams)
     {
       label = gtk_label_new("In :");
-      gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5); 
+      gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
       gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
-	   0, 1, row, row+(dbbrowser->selected_nparams), 
+	   0, 1, row, row+(dbbrowser->selected_nparams),
 	   GTK_FILL, GTK_FILL, 3, 0);
       gtk_widget_show(label);
-      for (i=0;i<(dbbrowser->selected_nparams);i++) 
+      for (i=0;i<(dbbrowser->selected_nparams);i++)
 	{
 	  /* name */
 	  label = gtk_label_new((dbbrowser->selected_params[i]).name);
-	  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5); 
+	  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	  gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
 			    1, 2, row, row+1, GTK_FILL, GTK_FILL, 0, 0);
 	  gtk_widget_show(label);
@@ -326,12 +330,12 @@ dialog_select (dbbrowser_t *dbbrowser,
 	  gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
 			    3, 4, row, row+1, GTK_FILL, GTK_FILL, 0, 0);
 	  gtk_widget_show(label);
-	  
+
 	  row++;
 	}
     }
-  
-  if ((dbbrowser->selected_nparams) && 
+
+  if ((dbbrowser->selected_nparams) &&
       (dbbrowser->selected_nreturn_vals)) {
     label = gtk_hseparator_new(); /* ok, not really a label ... :) */
     gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
@@ -345,18 +349,18 @@ dialog_select (dbbrowser_t *dbbrowser,
   if (dbbrowser->selected_nreturn_vals)
     {
       label = gtk_label_new("Out :");
-      gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5); 
+      gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
       gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
-			0, 1, row, row+(dbbrowser->selected_nreturn_vals), 
+			0, 1, row, row+(dbbrowser->selected_nreturn_vals),
 			GTK_FILL, GTK_FILL, 3, 0);
       gtk_widget_show(label);
-      for (i=0;i<(dbbrowser->selected_nreturn_vals);i++) 
+      for (i=0;i<(dbbrowser->selected_nreturn_vals);i++)
 	{
 	  /* name */
 	  label = gtk_label_new((dbbrowser->selected_return_vals[i]).name);
-	  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5); 
+	  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	  gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
-			    1, 2, row, row+1, 
+			    1, 2, row, row+1,
 			    GTK_FILL, GTK_FILL, 0, 0);
 	  gtk_widget_show(label);
 
@@ -364,15 +368,15 @@ dialog_select (dbbrowser_t *dbbrowser,
 	  label = gtk_label_new(GParamType2char((dbbrowser->selected_return_vals[i]).type));
 	  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	  gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
-			    2, 3, row, row+1, 
+			    2, 3, row, row+1,
 			    GTK_FILL, GTK_FILL, 0, 0);
 	  gtk_widget_show(label);
 
 	  /* description */
 	  label = gtk_label_new((dbbrowser->selected_return_vals[i]).description);
-	  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5); 
+	  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	  gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
-			    3, 4, row, row+1, 
+			    3, 4, row, row+1,
 			    GTK_FILL, GTK_FILL, 0, 0);
 	  gtk_widget_show(label);
 	  row++;
@@ -382,7 +386,7 @@ dialog_select (dbbrowser_t *dbbrowser,
 
   /* show the author & the copyright */
 
-  if ((dbbrowser->selected_nparams) || 
+  if ((dbbrowser->selected_nparams) ||
       (dbbrowser->selected_nreturn_vals)) {
     label = gtk_hseparator_new(); /* ok, not really a label ... :) */
     gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
@@ -393,9 +397,9 @@ dialog_select (dbbrowser_t *dbbrowser,
   }
 
   label = gtk_label_new("Author :");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5); 
+  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
-		    0, 1, row, row+1, 
+		    0, 1, row, row+1,
 		    GTK_FILL, GTK_FILL, 3, 0);
   gtk_widget_show(label);
 
@@ -406,11 +410,11 @@ dialog_select (dbbrowser_t *dbbrowser,
 		    GTK_FILL, GTK_FILL, 0, 0);
   gtk_widget_show(label);
   row++;
-  
+
   label = gtk_label_new("Date :");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5); 
+  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
-		    0, 1, row, row+1, 
+		    0, 1, row, row+1,
 		    GTK_FILL, GTK_FILL, 3, 0);
   gtk_widget_show(label);
 
@@ -423,9 +427,9 @@ dialog_select (dbbrowser_t *dbbrowser,
   row++;
 
   label = gtk_label_new("Copyright :");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5); 
+  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
-		    0, 1, row, row+1, 
+		    0, 1, row, row+1,
 		    GTK_FILL, GTK_FILL, 3, 0);
   gtk_widget_show(label);
 
@@ -439,9 +443,9 @@ dialog_select (dbbrowser_t *dbbrowser,
 
   /*
   label = gtk_label_new("Help :");
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5); 
+  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
   gtk_table_attach (GTK_TABLE (dbbrowser->descr_table), label,
-		    0, 1, row, row+1, 
+		    0, 1, row, row+1,
 		    GTK_FILL, GTK_FILL, 3, 0);
   gtk_widget_show(label);
 
@@ -449,13 +453,14 @@ dialog_select (dbbrowser_t *dbbrowser,
 
   if (old_table) gtk_widget_destroy(old_table);
 
-  gtk_container_add (GTK_CONTAINER (dbbrowser->descr_scroll), 
-		     dbbrowser->descr_table );
+  gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (dbbrowser->descr_scroll),
+					 dbbrowser->descr_table);
+
   gtk_widget_show(dbbrowser->descr_table);
 }
 
 static void
-dialog_close_callback (GtkWidget *widget, 
+dialog_close_callback (GtkWidget *widget,
 		       gpointer   data)
      /* end of the dialog */
 {
@@ -472,8 +477,8 @@ dialog_close_callback (GtkWidget *widget,
   }
 }
 
-static void 
-dialog_apply_callback (GtkWidget *widget, 
+static void
+dialog_apply_callback (GtkWidget *widget,
 		       gpointer   data)
      /* end of the dialog */
 {
@@ -493,8 +498,8 @@ dialog_apply_callback (GtkWidget *widget,
 			       dbbrowser->selected_return_vals );
 }
 
-static void 
-dialog_search_callback (GtkWidget *widget, 
+static void
+dialog_search_callback (GtkWidget *widget,
 			gpointer   data)
      /* search in the whole db */
 {
@@ -510,9 +515,9 @@ dialog_search_callback (GtkWidget *widget,
 
   /* search */
 
-  if ( widget == (dbbrowser->name_button) ) 
+  if ( widget == (dbbrowser->name_button) )
     {
-      gtk_window_set_title (GTK_WINDOW (dbbrowser->dlg), 
+      gtk_window_set_title (GTK_WINDOW (dbbrowser->dlg),
 			    "DB Browser (by name - please wait)");
 
       query = g_string_new ("");
@@ -529,24 +534,24 @@ dialog_search_callback (GtkWidget *widget,
 	}
 
       gimp_query_database (query->str,
-			   ".*", ".*", ".*", ".*", ".*", ".*", 
+			   ".*", ".*", ".*", ".*", ".*", ".*",
 			   &num_procs, &proc_list);
 
       g_string_free (query, TRUE);
     }
   else if ( widget == (dbbrowser->blurb_button) )
     {
-      gtk_window_set_title (GTK_WINDOW (dbbrowser->dlg), 
+      gtk_window_set_title (GTK_WINDOW (dbbrowser->dlg),
 			    "DB Browser (by blurb - please wait)");
-      gimp_query_database (".*", 
+      gimp_query_database (".*",
 			   gtk_entry_get_text( GTK_ENTRY(dbbrowser->search_entry) ),
 			   ".*", ".*", ".*", ".*", ".*",
 			   &num_procs, &proc_list);
     }
   else {
-      gtk_window_set_title (GTK_WINDOW (dbbrowser->dlg), 
+      gtk_window_set_title (GTK_WINDOW (dbbrowser->dlg),
 			    "DB Browser (please wait)");
-      gimp_query_database (".*", ".*", ".*", ".*", ".*", ".*", ".*", 
+      gimp_query_database (".*", ".*", ".*", ".*", ".*", ".*", ".*",
 			   &num_procs, &proc_list);
   }
 
@@ -562,7 +567,7 @@ dialog_search_callback (GtkWidget *widget,
     gtk_clist_insert (GTK_CLIST (GTK_CLIST(dbbrowser->clist)), j,
                       &label);
     func_name = g_strdup (proc_list[i]);
-    
+
     gtk_clist_set_row_data_full(GTK_CLIST(dbbrowser->clist), j,
                                 func_name, g_free);
   }
@@ -576,7 +581,7 @@ dialog_search_callback (GtkWidget *widget,
   if (num_procs != 0) {
     gchar *insert_name, *label_name;
     int i,j,savej;
-    
+
     for (i = 0; i < num_procs ; i++) {
 
       insert_name=g_strdup(proc_list[0]); savej=0;
@@ -587,7 +592,7 @@ dialog_search_callback (GtkWidget *widget,
 	  savej=j;
 	}
       }
-  
+
       proc_list[savej][0]='\255';
 
       label_name = g_strdup( insert_name );
@@ -600,14 +605,14 @@ dialog_search_callback (GtkWidget *widget,
     }
   }
   */
-  
+
   if ( dbbrowser->clist ) {
     ;
   }
-  
+
   g_free( proc_list );
 
-  gtk_window_set_title (GTK_WINDOW (dbbrowser->dlg), 
+  gtk_window_set_title (GTK_WINDOW (dbbrowser->dlg),
 			"DB Browser");
   gtk_clist_thaw(GTK_CLIST(dbbrowser->clist));
 
@@ -615,7 +620,7 @@ dialog_search_callback (GtkWidget *widget,
 
 /* utils ... */
 
-static void 
+static void
 convert_string (char *str)
 {
   while (*str)
@@ -625,7 +630,7 @@ convert_string (char *str)
     }
 }
 
-static char* 
+static char*
 GParamType2char(GParamType t)
 {
   switch (t) {
