@@ -1,5 +1,5 @@
 /*
- * "$Id: print-ps.c,v 1.9 1998/05/17 07:16:47 yosh Exp $"
+ * "$Id: print-ps.c,v 1.9.4.1 1998/08/28 01:58:15 yosh Exp $"
  *
  *   Print plug-in Adobe PostScript driver for the GIMP.
  *
@@ -32,6 +32,11 @@
  * Revision History:
  *
  *   $Log: print-ps.c,v $
+ *   Revision 1.9.4.1  1998/08/28 01:58:15  yosh
+ *   s/strdup/g_strdup/ for portability
+ *
+ *   -Yosh
+ *
  *   Revision 1.9  1998/05/17 07:16:47  yosh
  *   0.99.31 fun
  *
@@ -175,7 +180,7 @@ ps_parameters(int  model,	/* I - Printer model */
 
       valptrs = g_new(char *, 6);
       for (i = 0; i < 6; i ++)
-        valptrs[i] = strdup(media_sizes[i]);
+        valptrs[i] = g_strdup(media_sizes[i]);
 
       return (valptrs);
     }
@@ -198,7 +203,7 @@ ps_parameters(int  model,	/* I - Printer model */
 
     if (strcasecmp(lname, name) == 0)
     {
-      valptrs[*count] = strdup(loption);
+      valptrs[*count] = g_strdup(loption);
       (*count) ++;
     };
   };
@@ -532,28 +537,28 @@ ps_print(int       model,		/* I - Model (Level 1 or 2) */
 
   if ((command = ppd_find(ppd_file, "PageSize", media_size, &order)) != NULL)
   {
-    commands[num_commands].command = strdup(command);
+    commands[num_commands].command = g_strdup(command);
     commands[num_commands].order   = order;
     num_commands ++;
   };
 
   if ((command = ppd_find(ppd_file, "InputSlot", media_source, &order)) != NULL)
   {
-    commands[num_commands].command = strdup(command);
+    commands[num_commands].command = g_strdup(command);
     commands[num_commands].order   = order;
     num_commands ++;
   };
 
   if ((command = ppd_find(ppd_file, "MediaType", media_type, &order)) != NULL)
   {
-    commands[num_commands].command = strdup(command);
+    commands[num_commands].command = g_strdup(command);
     commands[num_commands].order   = order;
     num_commands ++;
   };
 
   if ((command = ppd_find(ppd_file, "Resolution", resolution, &order)) != NULL)
   {
-    commands[num_commands].command = strdup(command);
+    commands[num_commands].command = g_strdup(command);
     commands[num_commands].order   = order;
     num_commands ++;
   };
@@ -899,5 +904,5 @@ ppd_find(char *ppd_file,	/* I - Name of PPD file */
 
 
 /*
- * End of "$Id: print-ps.c,v 1.9 1998/05/17 07:16:47 yosh Exp $".
+ * End of "$Id: print-ps.c,v 1.9.4.1 1998/08/28 01:58:15 yosh Exp $".
  */
